==> plasma_2.6.0.tar.gz: plasma_2.6.0/docs/doxygen/out/html/modules.js <==
var modules =
[
    [ "Kernel Interface - Single Real", "group__CORE__float.html", "group__CORE__float" ],
    [ "Kerne Interface - Double Real", "group__CORE__double.html", "group__CORE__double" ],
    [ "Kerne Interface - Single Complex", "group__CORE__PLASMA__Complex32__t.html", "group__CORE__PLASMA__Complex32__t" ],
    [ "Kerne Interface - Double Complex", "group__CORE__PLASMA__Complex64__t.html", "group__CORE__PLASMA__Complex64__t" ],
    [ "Simple Interface - Single Real", "group__float.html", "group__float" ],
    [ "Simple Interface - Double Real", "group__double.html", "group__double" ],
    [ "Simple Interface - Single Complex", "group__PLASMA__Complex32__t.html", "group__PLASMA__Complex32__t" ],
    [ "Simple Interface - Double Complex", "group__PLASMA__Complex64__t.html", "group__PLASMA__Complex64__t" ],
    [ "Advanced Interface: Synchronous - Single Real", "group__float__Tile.html", "group__float__Tile" ],
    [ "Advanced Interface: Synchronous - Double Real", "group__double__Tile.html", "group__double__Tile" ],
    [ "Advanced Interface: Synchronous - Single Complex", "group__PLASMA__Complex32__t__Tile.html", "group__PLASMA__Complex32__t__Tile" ],
    [ "Advanced Interface: Synchronous - Double Complex", "group__PLASMA__Complex64__t__Tile.html", "group__PLASMA__Complex64__t__Tile" ],
    [ "Advanced Interface: Asynchronous - Single Real", "group__float__Tile__Async.html", "group__float__Tile__Async" ],
    [ "Advanced Interface: Asynchronous - Double Real", "group__double__Tile__Async.html", "group__double__Tile__Async" ],
    [ "Advanced Interface: Asynchronous - Single Complex", "group__PLASMA__Complex32__t__Tile__Async.html", "group__PLASMA__Complex32__t__Tile__Async" ],
    [ "Advanced Interface: Asynchronous - Double Complex", "group__PLASMA__Complex64__t__Tile__Async.html", "group__PLASMA__Complex64__t__Tile__Async" ]
];

==> plasma_2.7.1.tar.gz: plasma_2.7.1/docs/doxygen/out/html/modules.js <==
var modules =
[
    [ "Main subroutines", "group__Auxiliary.html", "group__Auxiliary" ],
    [ "Kernel Interface - Single Real", "group__CORE__float.html", "group__CORE__float" ],
    [ "Kernel Interface - Double Real", "group__CORE__double.html", "group__CORE__double" ],
    [ "Kernel Interface - Single Complex", "group__CORE__PLASMA__Complex32__t.html", "group__CORE__PLASMA__Complex32__t" ],
    [ "Kernel Interface - Double Complex", "group__CORE__PLASMA__Complex64__t.html", "group__CORE__PLASMA__Complex64__t" ],
    [ "Simple Interface - Single Real", "group__float.html", "group__float" ],
    [ "Simple Interface - Double Real", "group__double.html", "group__double" ],
    [ "Simple Interface - Single Complex", "group__PLASMA__Complex32__t.html", "group__PLASMA__Complex32__t" ],
    [ "Simple Interface - Double Complex", "group__PLASMA__Complex64__t.html", "group__PLASMA__Complex64__t" ],
    [ "Advanced Interface: Synchronous - Single Real", "group__float__Tile.html", "group__float__Tile" ],
    [ "Advanced Interface: Synchronous - Double Real", "group__double__Tile.html", "group__double__Tile" ],
    [ "Advanced Interface: Synchronous - Single Complex", "group__PLASMA__Complex32__t__Tile.html", "group__PLASMA__Complex32__t__Tile" ],
    [ "Advanced Interface: Synchronous - Double Complex", "group__PLASMA__Complex64__t__Tile.html", "group__PLASMA__Complex64__t__Tile" ],
    [ "Advanced Interface: Asynchronous - Single Real", "group__float__Tile__Async.html", "group__float__Tile__Async" ],
    [ "Advanced Interface: Asynchronous - Double Real", "group__double__Tile__Async.html", "group__double__Tile__Async" ],
    [ "Advanced Interface: Asynchronous - Single Complex", "group__PLASMA__Complex32__t__Tile__Async.html", "group__PLASMA__Complex32__t__Tile__Async" ],
    [ "Advanced Interface: Asynchronous - Double Complex", "group__PLASMA__Complex64__t__Tile__Async.html", "group__PLASMA__Complex64__t__Tile__Async" ]
];
